==> queueshare-0.0.55.tgz: package/src/qsQcWsServer.js <==
import collabThread from './collabThread.js'
import qcsCollabMap from './qcsCollabMap.js'
import qsCollabMapTimer from './qsCollabMapTimer.js'
import qsResetMaintenanceTimeout from './qsResetMaintenanceTimeout.js'
import RelativeUriAsUrl from './RelativeUriAsUrl.js'
import {WebSocketServer} from 'ws'

const qsQcWsServer = new WebSocketServer({noServer: true})
const clientsWithMatchingQsCollabThreads = new WeakSet()
qsQcWsServer.on('connection', (client, req) => {
	const searchParams = RelativeUriAsUrl(req.url).searchParams
	if (searchParams.get('qsCollabThread') === collabThread) {
		clientsWithMatchingQsCollabThreads.add(client)
		const opTimes = qsCollabMapTimer.opTimes
		const qcTime = JSON.parse(searchParams.get('qsCollabMapTime'))
		for (const op of qcsCollabMap.ops.values()) {
			if (opTimes.get(op) >= qcTime) {
				client.send(JSON.stringify({kind: 'collabMapCatchUpOp', value: op}))
			}
		}
		const time = qsCollabMapTimer.time
		client.send(JSON.stringify({kind: 'collabMapCatchUpTime', value: time}))
	} else {
		client.send(JSON.stringify({kind: 'qsCollabThreadMismatch', value: null}))
	}
	client.on('message', (messageAsBuffer) => {
		const message = JSON.parse(messageAsBuffer.toString())
		const kind = message.kind
		const value = message.value
		if (kind === 'collabMapOp') {
			if (clientsWithMatchingQsCollabThreads.has(client)) {
				qcsCollabMap.receive(value)
				qsResetMaintenanceTimeout()
				client.send(JSON.stringify({kind: 'collabMapOpConfirmation', value: null}))
			}
		} else if (kind === 'ping') {
			client.send(JSON.stringify({kind: 'pong', value: null}))
		}
	})
})
qcsCollabMap.changeHandlers.push((change) => {
	for (const client of qsQcWsServer.clients) {
		if (client.readyState === 1 && clientsWithMatchingQsCollabThreads.has(client)) {
			client.send(JSON.stringify({kind: 'collabMapOp', value: change.op}))
		}
	}
})

export default qsQcWsServer

==> queueshare-0.0.57.tgz: package/src/qsQcWsServer.js <==
import collabThread from './collabThread.js'
import qcsCollabMap from './qcsCollabMap.js'
import qsCollabMapTimer from './qsCollabMapTimer.js'
import qsResetMaintenanceTimeout from './qsResetMaintenanceTimeout.js'
import RelativeUriAsUrl from './RelativeUriAsUrl.js'
import {WebSocketServer} from 'ws'

const qsQcWsServer = new WebSocketServer({noServer: true})
const clientsWithMatchingQsCollabThreads = new WeakSet()
qsQcWsServer.on('connection', (client, req) => {
	const searchParams = RelativeUriAsUrl(req.url).searchParams
	if (searchParams.get('qsCollabThread') === collabThread) {
		clientsWithMatchingQsCollabThreads.add(client)
		const opTimes = qsCollabMapTimer.opTimes
		const qcTime = JSON.parse(searchParams.get('qsCollabMapTime'))
		for (const op of qcsCollabMap.ops.values()) {
			if (opTimes.get(op) >= qcTime) {
				client.send(JSON.stringify({kind: 'collabMapCatchUpOp', value: op}))
			}
		}
		const time = qsCollabMapTimer.time
		client.send(JSON.stringify({kind: 'collabMapCatchUpTime', value: time}))
	}
	else {
		client.send(JSON.stringify({kind: 'qsCollabThreadMismatch', value: null}))
	}
	client.on('message', (messageAsBuffer) => {
		const message = JSON.parse(messageAsBuffer.toString())
		const kind = message.kind
		const value = message.value
		if (kind === 'collabMapOp') {
			if (clientsWithMatchingQsCollabThreads.has(client)) {
				qcsCollabMap.receive(value)
				qsResetMaintenanceTimeout()
				client.send(JSON.stringify({kind: 'collabMapOpConfirmation', value: null}))
			}
		}
		else if (kind === 'ping') {
			client.send(JSON.stringify({kind: 'pong', value: null}))
		}
	})
})
qcsCollabMap.changeHandlers.push((change) => {
	for (const client of qsQcWsServer.clients) {
		if (client.readyState === 1 && clientsWithMatchingQsCollabThreads.has(client)) {
			client.send(JSON.stringify({kind: 'collabMapOp', value: change.op}))
		}
	}
})

export default qsQcWsServer
